@@ -7,7 +7,7 @@ from kweb.main import app
 jupyter_server = None
 
 
-def _run():
+def _run() -> None:
     config = uvicorn.Config(app)
     jupyter_server = uvicorn.Server(config)
     loop = asyncio.get_event_loop()
@@ -18,6 +18,7 @@ def _server_is_running() -> bool:
     return False if jupyter_server is None else jupyter_server.started
 
 
-def start():
+def start() -> None:
+    """Start a jupyter_server if it's nor already started."""
     if not _server_is_running():
         _run()
